###################################################
# R code for "Big Data: New Tricks for Econometrics
# Journal of Economic Perspectives 28(2), 3-28            
# http://pubs.aeaweb.org/doi/pdfplus/10.1257/jep.28.2.3
# Hal R. Varian
###################################################

dat <- read.csv("titanic3.csv")
mydat <- na.omit(with(dat,data.frame(survived,age)))
library(rpart)

# fit very simple tree model
model.rpart <- rpart(survived ~ age, data=mydat)
model.rpart

# fit very simple logit model
model.logit <- glm(survived ~ age, data=mydat)
summary(model.logit)
# compute confidence intervals and plot them
attach(mydat)
age.bins <- cut(age,seq(0,80,10))
num.in.bin <- tapply(survived,age.bins,length)
num.survived <- tapply(survived,age.bins,sum)
frac.survived <- tapply(survived,age.bins,mean)

# confidence intervals
library(binom)
temp <- binom.confint(num.survived, num.in.bin,methods="wilson")
temp
ymean <- temp[,4]
ymin <- temp[,5]
ymax <- temp[,6]

# library for misc plots
library(gplots)

plotCI(x=seq(10,80,10),y=ymean,ui=ymax,li=ymin,col="black",barcol="blue",xlab="age bin",ylab="fraction survived",cex.axis=1.5,cex.lab=1.5)

# generate Figure 3 in paper
pdf("survival-by-age.pdf")
plotCI(x=seq(10,80,10),y=ymean,ui=ymax,li=ymin,col="black",barcol="blue",xlab="age bin",ylab="fraction survived",cex.axis=1.5,cex.lab=1.5)
graphics.off()
